// SPDX-License-Identifier: GPL-2.0
/*
 * Maxim GMSL2 Pattern Generator
 *
 * Copyright (C) 2023 Collabora Ltd.
 */

#ifndef __LINUX_MEDIA_MAX_GMSL2_PATGEN_H
#define __LINUX_MEDIA_MAX_GMSL2_PATGEN_H

#include <linux/regmap.h>
#include <linux/types.h>
#include <linux/videodev2.h>

enum max_gmsl2_vpg_mode
{
	MAX_GMSL2_VPG_DISABLED = 0,
	MAX_GMSL2_VPG_CHECKERBOARD = 1,
	MAX_GMSL2_VPG_GRADIENT = 2,
};

static const char * const max_gmsl2_test_pattern[] = {
	"Disabled",
	"Checkerboard",
	"Gradient"
};

struct max_gmsl2_patgen {
	struct regmap_field *gen_vs_hs_de;
	struct regmap_field *inv_vs_hs_de;
	struct regmap_field *vtg_mode;
	struct regmap_field *vpg_mode;
	u16 vtg_timing;
	u16 vpg_patterns;
	struct regmap_field *pattern_clk_freq;
};

int max_gmsl2_vtg_enable(struct max_gmsl2_patgen *patgen,
			 struct regmap *regmap,
			 const struct v4l2_bt_timings *t);
int max_gmsl2_vtg_disable(struct max_gmsl2_patgen *patgen, struct regmap *regmap);
int max_gmsl2_vpg_enable(struct max_gmsl2_patgen *patgen, struct regmap *regmap,
			 enum max_gmsl2_vpg_mode mode);
int max_gmsl2_vpg_disable(struct max_gmsl2_patgen *patgen);
#endif /* __LINUX_MEDIA_MAX_GMSL2_PATGEN_H */
